@@ -17,13 +17,13 @@
         <location filename="mainwindow.ui" line="76"/>
         <location filename="ui_mainwindow.h" line="757"/>
         <source>IP address</source>
-        <translation type="unfinished"/>
+        <translation>IP-adresse</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="112"/>
         <location filename="ui_mainwindow.h" line="760"/>
         <source>Hardware detected</source>
-        <translation type="unfinished"/>
+        <translation>Gjenkjente maskinvare</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="143"/>
@@ -33,121 +33,121 @@
         <location filename="ui_mainwindow.h" line="774"/>
         <location filename="ui_mainwindow.h" line="780"/>
         <source>Re-scan</source>
-        <translation type="unfinished"/>
+        <translation>Nytt søk</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="215"/>
         <location filename="ui_mainwindow.h" line="762"/>
         <source>Active interface</source>
-        <translation type="unfinished"/>
+        <translation>Aktivt grensesnitt</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="231"/>
         <location filename="ui_mainwindow.h" line="764"/>
         <source>WiFi status</source>
-        <translation type="unfinished"/>
+        <translation>Wi-Fi-status</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="253"/>
         <location filename="ui_mainwindow.h" line="767"/>
         <source>Unblocks all soft/hard blocked wireless devices</source>
-        <translation type="unfinished"/>
+        <translation>Avblokkerer alle myk-/hardblokkerte trådløse enheter</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="256"/>
         <location filename="ui_mainwindow.h" line="769"/>
         <source>Unblock WiFi Devices</source>
-        <translation type="unfinished"/>
+        <translation>Avblokker Wi-Fi-enheter</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="288"/>
         <location filename="ui_mainwindow.h" line="776"/>
         <source>Linux drivers</source>
-        <translation type="unfinished"/>
+        <translation>Linux-drivere</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="300"/>
         <location filename="ui_mainwindow.h" line="771"/>
         <source>Associated Linux drivers</source>
-        <translation type="unfinished"/>
+        <translation>Tilhørende Linux-drivere</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="309"/>
         <location filename="ui_mainwindow.h" line="772"/>
         <source>Load Driver</source>
-        <translation type="unfinished"/>
+        <translation>Last inn driver</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="372"/>
         <location filename="ui_mainwindow.h" line="773"/>
         <source>Unload Driver</source>
-        <translation type="unfinished"/>
+        <translation>Last ut driver</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="409"/>
         <location filename="ui_mainwindow.h" line="775"/>
         <source>Block Driver</source>
-        <translation type="unfinished"/>
+        <translation>Blokker driver</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="428"/>
         <location filename="ui_mainwindow.h" line="785"/>
         <source>Windows drivers</source>
-        <translation type="unfinished"/>
+        <translation>Windows-drivere</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="434"/>
         <location filename="ui_mainwindow.h" line="777"/>
         <source>Available Windows drivers</source>
-        <translation type="unfinished"/>
+        <translation>Tilgjengelige Windows-drivere</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="468"/>
         <location filename="ui_mainwindow.h" line="778"/>
         <source>Remove Driver</source>
-        <translation type="unfinished"/>
+        <translation>Fjern driver</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="479"/>
         <location filename="ui_mainwindow.h" line="779"/>
         <source>Add Driver</source>
-        <translation type="unfinished"/>
+        <translation>Legg til driver</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="520"/>
         <location filename="ui_mainwindow.h" line="781"/>
         <source>About NDISwrapper</source>
-        <translation type="unfinished"/>
+        <translation>Om NDISwrapper</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="532"/>
         <location filename="ui_mainwindow.h" line="782"/>
         <source>Install NDISwrapper</source>
-        <translation type="unfinished"/>
+        <translation>Installer NDISwrapper</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="543"/>
         <location filename="ui_mainwindow.h" line="783"/>
         <source>In order to use Windows drivers you need first to install NDISwrapper</source>
-        <translation type="unfinished"/>
+        <translation>For å ta i bruk Windows-drivere må NDISwrapper installeres først</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="559"/>
         <location filename="ui_mainwindow.h" line="784"/>
         <source>Uninstall NDISwrapper</source>
-        <translation type="unfinished"/>
+        <translation>Avinstaller NDISwrapper</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="591"/>
         <location filename="ui_mainwindow.h" line="798"/>
         <source>Net diagnostics</source>
-        <translation type="unfinished"/>
+        <translation>Nettdiagnostikk</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="603"/>
         <location filename="ui_mainwindow.h" line="786"/>
         <source>Ping</source>
-        <translation type="unfinished"/>
+        <translation>Ping</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="609"/>
@@ -155,13 +155,13 @@
         <location filename="ui_mainwindow.h" line="787"/>
         <location filename="ui_mainwindow.h" line="793"/>
         <source>Target URL:</source>
-        <translation type="unfinished"/>
+        <translation>Mål-URL:</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="619"/>
         <location filename="ui_mainwindow.h" line="788"/>
         <source>Packets</source>
-        <translation type="unfinished"/>
+        <translation>Pakker</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="661"/>
@@ -177,7 +177,7 @@
         <location filename="ui_mainwindow.h" line="790"/>
         <location filename="ui_mainwindow.h" line="796"/>
         <source>Clear</source>
-        <translation type="unfinished"/>
+        <translation>Tøm</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="692"/>
@@ -191,19 +191,19 @@
         <location filename="mainwindow.ui" line="720"/>
         <location filename="ui_mainwindow.h" line="792"/>
         <source>Traceroute</source>
-        <translation type="unfinished"/>
+        <translation>Traceroute</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="736"/>
         <location filename="ui_mainwindow.h" line="794"/>
         <source>Hops</source>
-        <translation type="unfinished"/>
+        <translation>Hopp</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="868"/>
         <location filename="ui_mainwindow.h" line="799"/>
         <source>About...</source>
-        <translation>Om...</translation>
+        <translation>Om …</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="891"/>
@@ -221,153 +221,153 @@
         <location filename="mainwindow.ui" line="966"/>
         <location filename="ui_mainwindow.h" line="807"/>
         <source>Alt+C</source>
-        <translation type="unfinished"/>
+        <translation>Alt + C</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="87"/>
         <source>IP address from router:</source>
-        <translation type="unfinished"/>
+        <translation>IP-adresse fra ruter:</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="88"/>
         <source>External IP address:</source>
-        <translation type="unfinished"/>
+        <translation>Ekstern IP-adresse:</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="196"/>
         <location filename="mainwindow.cpp" line="210"/>
         <location filename="mainwindow.cpp" line="224"/>
         <source>&amp;Copy</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Kopier</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="198"/>
         <location filename="mainwindow.cpp" line="212"/>
         <location filename="mainwindow.cpp" line="226"/>
         <source>Ctrl+C</source>
-        <translation>Ctrl+C</translation>
+        <translation>Ctrl + C</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="199"/>
         <location filename="mainwindow.cpp" line="213"/>
         <location filename="mainwindow.cpp" line="227"/>
         <source>Copy &amp;All</source>
-        <translation type="unfinished"/>
+        <translation>Kopier &amp;alt</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="201"/>
         <location filename="mainwindow.cpp" line="215"/>
         <location filename="mainwindow.cpp" line="229"/>
         <source>Ctrl+A</source>
-        <translation>Ctrl+A</translation>
+        <translation>Ctrl + A</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="261"/>
         <location filename="mainwindow.cpp" line="278"/>
         <source>Traceroute not installed</source>
-        <translation type="unfinished"/>
+        <translation>Traceroute er ikke installert</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="262"/>
         <source>Traceroute is not installed, do you want to install it now?</source>
-        <translation type="unfinished"/>
+        <translation>Traceroute er ikke installert – vil du installere det nå?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="269"/>
         <source>Traceroute hasn&apos;t been installed</source>
-        <translation type="unfinished"/>
+        <translation>Traceroute ble ikke installert</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="270"/>
         <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
-        <translation type="unfinished"/>
+        <translation>Traceroute kan ikke installeres. Det kan være at du bruker live-CD eller ikke kan nå pakkearkivet,</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="279"/>
         <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
-        <translation type="unfinished"/>
+        <translation>Traceroute er ikke installert, og internett-tilkobling mangler slik at det ikke kan installeres </translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="285"/>
         <location filename="mainwindow.cpp" line="326"/>
         <source>No destination host</source>
-        <translation type="unfinished"/>
+        <translation>Mangler målvert</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="286"/>
         <location filename="mainwindow.cpp" line="327"/>
         <source>Please fill in the destination host field</source>
-        <translation type="unfinished"/>
+        <translation>Fyll inn feltet målvert</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="440"/>
         <source>Loaded Drivers</source>
-        <translation type="unfinished"/>
+        <translation>Lastet inn drivere</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="449"/>
         <source>Unloaded Drivers</source>
-        <translation type="unfinished"/>
+        <translation>Lastet ut drivere</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="464"/>
         <source>Blocked Drivers</source>
-        <translation type="unfinished"/>
+        <translation>Blokkerte drivere</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="486"/>
         <source>Blocked Broadcom Drivers</source>
-        <translation type="unfinished"/>
+        <translation>Blokkerte Broadcom-drivere</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="894"/>
         <source>enabled</source>
-        <translation type="unfinished"/>
+        <translation>slått på</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="897"/>
         <source>disabled</source>
-        <translation type="unfinished"/>
+        <translation>slått av</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="900"/>
         <source>WiFi hardware switch is off</source>
-        <translation type="unfinished"/>
+        <translation>Wi-Fi-maskinvarebryter er slått av</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="908"/>
         <source>Locate the Windows driver you want to add</source>
-        <translation type="unfinished"/>
+        <translation>Finn Windows-driveren som skal legges til</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="908"/>
         <source>Windows installation information file (*.inf)</source>
-        <translation type="unfinished"/>
+        <translation>Windows installasjonsinformasjonsfil (*.inf)</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="939"/>
         <source>*.sys file not found</source>
-        <translation type="unfinished"/>
+        <translation>Fant ikke *.sys-fil</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="939"/>
         <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
-        <translation type="unfinished"/>
+        <translation>*.sys-filene må ligge sammen med *.inf-fila. Fant ikke %1</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="948"/>
         <source>sys file reference not found</source>
-        <translation type="unfinished"/>
+        <translation>Fant ikke sys-fil-referanse</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="948"/>
         <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
-        <translation type="unfinished"/>
+        <translation>Klarte ikke fastslå sys-fil for gitt driver etter fortolkning av inf-fil</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="967"/>
         <source>Ndiswrapper driver removed.</source>
-        <translation type="unfinished"/>
+        <translation>Fjernet NDISwrapper-driver.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="975"/>
@@ -387,12 +387,12 @@
     <message>
         <location filename="mainwindow.cpp" line="1014"/>
         <source>Program for troubleshooting and configuring network for antiX Linux</source>
-        <translation type="unfinished"/>
+        <translation>Program for feilsøking og oppsett av nettverk for antiX Linux</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="1016"/>
         <source>Copyright (c) MEPIS LLC and MX Linux</source>
-        <translation type="unfinished"/>
+        <translation>Opphavsrett (c) MEPIS LLC og MX Linux</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="1017"/>
@@ -411,7 +411,7 @@
         <location filename="about.cpp" line="33"/>
         <location filename="about.cpp" line="43"/>
         <source>Changelog</source>
-        <translation>Changelog</translation>
+        <translation>Endringslogg</translation>
     </message>
     <message>
         <location filename="about.cpp" line="34"/>
@@ -431,91 +431,92 @@
     <message>
         <location filename="mainwindow.cpp" line="509"/>
         <source>Ndiswrapper is not installed</source>
-        <translation type="unfinished"/>
+        <translation>NDISwrapper er ikke installert</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="521"/>
         <source>driver installed</source>
-        <translation type="unfinished"/>
+        <translation>driver er installert</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="529"/>
         <source> and in use by </source>
-        <translation type="unfinished"/>
+        <translation>og brukes av</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="536"/>
         <source>. Alternate driver: </source>
-        <translation type="unfinished"/>
+        <translation>. Alternativ driver:</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="613"/>
         <source>Driver removed from blocklist</source>
-        <translation type="unfinished"/>
+        <translation>Fjernet driver fra blokkliste</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="614"/>
         <source>Driver removed from blocklist.</source>
-        <translation type="unfinished"/>
+        <translation>Fjernet driver fra blokkliste.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="620"/>
         <location filename="mainwindow.cpp" line="621"/>
         <source>Module blocked</source>
-        <translation type="unfinished"/>
+        <translation>Modul blokkert</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="786"/>
         <source>Installation successful</source>
-        <translation type="unfinished"/>
+        <translation>Fullførte installasjon</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="789"/>
         <source>Error detected, could not compile ndiswrapper driver.</source>
-        <translation type="unfinished"/>
+        <translation>Oppdaget feil – klarte ikke kompilere NDISwrapper-driver.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="792"/>
         <source>Error detected, could not install ndiswrapper.</source>
-        <translation type="unfinished"/>
+        <translation>Oppdaget feil – klarte ikke installere NDISwrapper.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="804"/>
         <source>Error encountered while removing Ndiswrapper</source>
-        <translation type="unfinished"/>
+        <translation>Oppdaget feil ved fjerning av NDISwrapper</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="855"/>
         <source>Unblock Driver</source>
-        <translation type="unfinished"/>
+        <translation>Avblokker driver</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="858"/>
         <source>Block Driver</source>
-        <translation type="unfinished"/>
+        <translation>Blokker driver</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="995"/>
         <source>Could not unlock devices.
 WiFi device(s) might already be unlocked.</source>
-        <translation type="unfinished"/>
+        <translation>Klarte ikke låse opp enheter.
+Wi-Fi-enhet(er) kan allerede være låst opp.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="997"/>
         <source>WiFi devices unlocked.</source>
-        <translation type="unfinished"/>
+        <translation>Låste opp Wi-Fi-enheter.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="1040"/>
         <location filename="mainwindow.cpp" line="1041"/>
         <source>Driver loaded successfully</source>
-        <translation type="unfinished"/>
+        <translation>Lastet inn driver</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="1056"/>
         <location filename="mainwindow.cpp" line="1057"/>
         <source>Driver unloaded successfully</source>
-        <translation type="unfinished"/>
+        <translation>Lastet ut driver</translation>
     </message>
 </context>
 <context>
@@ -523,12 +524,12 @@ WiFi device(s) might already be unlocked.</source>
     <message>
         <location filename="mainwindow.cpp" line="638"/>
         <source>Could not load </source>
-        <translation type="unfinished"/>
+        <translation>Klarte ikke laste inn</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="669"/>
         <source>Could not unload </source>
-        <translation type="unfinished"/>
+        <translation>Klarte ikke laste ut</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
